@@ -19,6 +19,7 @@
 #include "errno.hpp"
 #include "fileinfo.hpp"
 #include "fs_base_stat.hpp"
+#include "fs_inode.hpp"
 
 static
 int
@@ -28,8 +29,12 @@ _fgetattr(const int    fd,
   int rv;
 
   rv = fs::fstat(fd,st);
+  if(rv == -1)
+    return -errno;
 
-  return ((rv == -1) ? -errno : 0);
+  fs::inode::recompute(st);
+
+  return 0;
 }
 
 namespace mergerfs
@@ -43,8 +48,7 @@ namespace mergerfs
     {
       FileInfo *fi = reinterpret_cast<FileInfo*>(ffi->fh);
 
-      return _fgetattr(fi->fd,
-                       *st);
+      return _fgetattr(fi->fd,*st);
     }
   }
 }
