@@ -24,6 +24,7 @@
 
 #include "config.hpp"
 #include "errno.hpp"
+#include "fs_base_truncate.hpp"
 #include "fs_path.hpp"
 #include "rv.hpp"
 #include "rwlock.hpp"
@@ -45,7 +46,7 @@ _truncate_loop_core(const string *basepath,
 
   fs::path::make(basepath,fusepath,fullpath);
 
-  rv = ::truncate(fullpath.c_str(),size);
+  rv = fs::truncate(fullpath,size);
 
   return calc_error(rv,error,errno);
 }
