@@ -16,15 +16,22 @@
 
 #include <fuse.h>
 
-#include <unistd.h>
-
 #include "config.hpp"
 #include "errno.hpp"
 #include "fileinfo.hpp"
+#include "fs_base_write.hpp"
 #include "fs_movefile.hpp"
 #include "rwlock.hpp"
 #include "ugid.hpp"
 
+static
+bool
+_out_of_space(const int error)
+{
+  return ((error == ENOSPC) ||
+          (error == EDQUOT));
+}
+
 static
 int
 _write(const int     fd,
@@ -34,7 +41,7 @@ _write(const int     fd,
 {
   int rv;
 
-  rv = ::pwrite(fd,buf,count,offset);
+  rv = fs::pwrite(fd,buf,count,offset);
 
   return ((rv == -1) ? -errno : rv);
 }
@@ -54,7 +61,7 @@ namespace mergerfs
       FileInfo* fi = reinterpret_cast<FileInfo*>(ffi->fh);
 
       rv = _write(fi->fd,buf,count,offset);
-      if(rv == -ENOSPC)
+      if(_out_of_space(-rv))
         {
           const fuse_context *fc     = fuse_get_context();
           const Config       &config = Config::get(fc);
