@@ -18,14 +18,10 @@
 #include <attr/xattr.h>
 #endif
 
-#ifndef ENOATTR
-#define ENOATTR ENODATA
-#endif
-
 #ifndef XATTR_CREATE
-#define XATTR_CREATE 0x1
+# define XATTR_CREATE 0x1
 #endif
 
 #ifndef XATTR_REPLACE
-#define XATTR_REPLACE 0x2
+# define XATTR_REPLACE 0x2
 #endif
